# Generated by Django 2.0.2 on 2018-05-01 08:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('postie', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='letter',
            name='recipients',
            field=models.TextField(help_text='Enter email address separated by commas', verbose_name='Letter recipients'),
        ),
    ]
