# Generated by Django 2.1 on 2020-03-23 17:54

import ckeditor.fields
from django.db import migrations, models
import django.db.models.deletion
import parler.fields


class Migration(migrations.Migration):

    dependencies = [
        ('postie', '0003_auto_20180504_0340'),
    ]

    operations = [
        migrations.AlterField(
            model_name='letter',
            name='html',
            field=ckeditor.fields.RichTextField(blank=True, null=True, verbose_name='HTML'),
        ),
        migrations.AlterField(
            model_name='letter',
            name='plain',
            field=models.TextField(blank=True, null=True, verbose_name='Plain text'),
        ),
        migrations.AlterField(
            model_name='log',
            name='letter',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='letter_logs', to='postie.Letter', verbose_name='Letter'),
        ),
        migrations.AlterField(
            model_name='templatetranslation',
            name='html',
            field=models.TextField(blank=True, help_text='Write variables inside {{  }}.', null=True, verbose_name='HTML text'),
        ),
        migrations.AlterField(
            model_name='templatetranslation',
            name='master',
            field=parler.fields.TranslationsForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='translations', to='postie.Template'),
        ),
        migrations.AlterField(
            model_name='templatetranslation',
            name='plain',
            field=models.TextField(blank=True, help_text='Alternative version of html text.Write variables inside {{  }}.', null=True, verbose_name='Plain text'),
        ),
        migrations.AlterField(
            model_name='templatetranslation',
            name='subject',
            field=models.CharField(help_text='Write variables inside {{  }}.', max_length=255, null=True, verbose_name='Subject'),
        ),
    ]
