# Generated by Django 2.1 on 2020-07-08 18:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tilda', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='preferences',
            name='project_id',
            field=models.PositiveIntegerField(blank=True, null=True, verbose_name='Private key'),
        ),
    ]
